@@ -41,7 +41,7 @@ from mitosheet.sheet_functions.types import *
 
 # Make sure the user is initalized
 initialize_user()
-log('imported_mitosheet')
+log('imported_mitosheet', check_mitosheet_install=True)
 
 # This function is only necessary for mitosheet3, as it is used
 # in jlab3 to find the extension. It is not used in jlab2
