@@ -12,7 +12,9 @@ from threading import Thread
 
 from mitosheet.mito_analytics import log_event_processed
 from mitosheet.api.get_graph import get_graph
+from mitosheet.api.get_path_join import get_path_join
 from mitosheet.api.get_datafiles import get_datafiles
+from mitosheet.api.get_path_contents import get_path_contents
 from mitosheet.api.get_column_dtype import get_column_dtype
 from mitosheet.api.get_import_summary import get_import_summary
 from mitosheet.api.get_column_describe import get_column_describe
@@ -98,18 +100,28 @@ def handle_api_event(send, event, wsc):
 
     # And then handle it
     if event['type'] == 'datafiles':
-        get_datafiles(send, event)
+        result = get_datafiles(event)
+    elif event['type'] == 'get_path_contents':
+        result = get_path_contents(event)
+    elif event['type'] == 'get_path_join':
+        result = get_path_join(event)
     elif event['type'] == 'import_summary':
-        get_import_summary(send, event)
+        result = get_import_summary(event)
     elif event['type'] == 'get_dataframe_as_csv':
-        get_dataframe_as_csv(send, event, wsc)
+        result = get_dataframe_as_csv(event, wsc)
     elif event['type'] == 'get_graph':
-        get_graph(send, event, wsc)
+        result = get_graph(event, wsc)
     elif event['type'] == 'get_column_describe':
-        get_column_describe(send, event, wsc)
+        result = get_column_describe(event, wsc)
     elif event['type'] == 'get_column_dtype':
-        get_column_dtype(send, event, wsc)
+        result = get_column_dtype(event, wsc)
     elif event['type'] == 'get_saved_analysis_description':
-        get_saved_analysis_description(send, event, wsc)
+        result = get_saved_analysis_description(event, wsc)
     else:
-        raise Exception(f'Event: {event} is not a valid API call')
\ No newline at end of file
+        raise Exception(f'Event: {event} is not a valid API call')
+    
+    send({
+        'event': 'api_response',
+        'id': event['id'],
+        'data': result
+    })
