@@ -1,6 +1,6 @@
 
 
-def get_column_dtype(send, event, wsc):
+def get_column_dtype(event, wsc):
     """
     Sends back the dtype of the column
     """
@@ -9,8 +9,4 @@ def get_column_dtype(send, event, wsc):
 
     series = wsc.dfs[sheet_index][column_header]
 
-    send({
-        'event': 'api_response',
-        'id': event['id'],
-        'data': str(series.dtype)
-    })
+    return str(series.dtype)
\ No newline at end of file
