@@ -18,6 +18,8 @@ Our general approach to logging can be understood as:
    This appears to be good practice, as it allows us to associate what actions are taken
    with their result very effectively!
 """
+import platform
+import getpass
 import sys
 import subprocess
 
@@ -88,6 +90,26 @@ def get_jupyterlab_version():
 
     return jupyterlab_version
 
+def get_jupyter_labextension_list():
+    """
+    This gets the current output from the command `jupyter labextension list`
+    which is very helpful in debugging the users installation.
+
+
+    Because this function can be _very_ expensive to run for some users, we should
+    only use this sparingly and not during every log event!
+
+    Further note: this function is non critical, so we do _not_ throw errors
+    when this fails, and instead just log the error and continue.
+    """
+    try:
+        completed_process_mitosheet3 = subprocess.run([sys.executable, '-m', 'jupyter', 'labextension', 'list'], capture_output=True)
+        all_output = completed_process_mitosheet3.stdout.decode() + completed_process_mitosheet3.stderr.decode()
+        return all_output.splitlines()
+    except Exception as e:
+        log_recent_error('get_jupyerlab_extension_list_failed')
+        return []
+
 def get_installed_mitosheets_pip_show():
     """
     This gets the version of mitosheet and mitosheet3 that are installed
@@ -97,17 +119,23 @@ def get_installed_mitosheets_pip_show():
 
     Because this function can be expensive to run for some users, we should
     only use this sparingly and not during every log event!
+
+    Further note: this function is non critical, so we do _not_ throw errors
+    when this fails, and instead just log the error and continue.
     """
-    completed_process_mitosheet3 = subprocess.run([sys.executable, '-m', 'pip', 'show', 'mitosheet3'], capture_output=True)
-    all_output = completed_process_mitosheet3.stdout.decode() + completed_process_mitosheet3.stderr.decode()
-    
-    completed_process_mitosheet = subprocess.run([sys.executable, '-m', 'pip', 'show', 'mitosheet'], capture_output=True)
-    all_output += completed_process_mitosheet.stdout.decode() + completed_process_mitosheet.stderr.decode()
-
-    return all_output.splitlines()
+    try:
+        completed_process_mitosheet3 = subprocess.run([sys.executable, '-m', 'pip', 'show', 'mitosheet3'], capture_output=True)
+        all_output = completed_process_mitosheet3.stdout.decode() + completed_process_mitosheet3.stderr.decode()
+        
+        completed_process_mitosheet = subprocess.run([sys.executable, '-m', 'pip', 'show', 'mitosheet'], capture_output=True)
+        all_output += completed_process_mitosheet.stdout.decode() + completed_process_mitosheet.stderr.decode()
+        return all_output.splitlines()
+    except Exception as e:
+        log_recent_error('get_installed_mitosheets_pip_show_failed')
+        return []
 
 
-def log(log_event, params=None, install_mitosheets_pip_show=False):
+def log(log_event, params=None, check_mitosheet_install=False):
     """
     Helper function that logs an event with the given parameters. However,
     this function is also responsible for making sure _zero_ private data
@@ -117,7 +145,7 @@ def log(log_event, params=None, install_mitosheets_pip_show=False):
     with a private secret that only the user has, making it impossible
     for us to brute force it.
 
-    NOTE: install_mitosheets_pip_show can be an expensive operation for some
+    NOTE: check_mitosheet_install can be an expensive operation for some
     users, so we should try and minimize where / how we use it!
     """
     if params is None:
@@ -130,15 +158,20 @@ def log(log_event, params=None, install_mitosheets_pip_show=False):
         'version_mito': __version__ 
     }
     
-    if install_mitosheets_pip_show:
+    if check_mitosheet_install:
         pip_shows = get_installed_mitosheets_pip_show()
+        jupyter_labextension_list = get_jupyter_labextension_list()
     else:
         pip_shows = []
-
+        jupyter_labextension_list = []
+    
     params = dict(
         **params,
         **python_properties,
-        **{'pip_shows': pip_shows}
+        **{
+            'pip_shows': pip_shows,
+            'jupyter_labextension_list': jupyter_labextension_list
+        }
     )
 
     # Private params are where we _make sure_ that no private
@@ -214,6 +247,8 @@ def identify():
     feedbacks = get_user_field(UJ_FEEDBACKS)
     local = is_local_deployment()
     jupyterlab_version = get_jupyterlab_version()
+    operating_system = platform.system()
+
     
     if not is_running_test():
         # NOTE: we do not log anything when tests are running
@@ -221,6 +256,8 @@ def identify():
             'version_python': sys.version_info,
             'version_mito': __version__,
             'version_jupyterlab': jupyterlab_version,
+            'user': getpass.getuser(),
+            'operating_system': operating_system,
             'email': user_email,
             'local': local,
             UJ_INTENDED_BEHAVIOR: intended_behavior,
