@@ -54,15 +54,9 @@ def FILLNAN(series: pd.Series, replacement: pd.Series) -> pd.Series:
         ]
     }
     """
-    # Make copy of the series as to not fill the nan values in the series itself
-    series_copy = series.copy(True)
-    nan_indexes = series_copy.isna()
-    for idx in range(len(nan_indexes)):
-        if nan_indexes[idx]:
-            series_copy[idx] = replacement[0]
-
-    return series_copy
-
+    # Do a replacement with the first item in the series
+    replacement = replacement[0]
+    return series.fillna(replacement)
 
 @handle_sheet_function_errors
 @filter_nans
