@@ -6,6 +6,7 @@
 
 import pytest
 
+from mitosheet.user.schemas import USER_JSON_DEFAULT
 from mitosheet.steps import STEPS
 from mitosheet.steps.pivot import PIVOT_AGGREGATION_TYPES
 from mitosheet.steps.sort import ASCENDING, DESCENDING
@@ -113,4 +114,9 @@ def test_pivot_aggregation_functions_match():
 
 def test_step_types_match():
     step_types = get_enum_from_ts_file('./src/types/StepTypes.ts', 'StepType')
-    assert set(step_types.values()) == set([step_object['step_type'] for step_object in STEPS] + ['initialize'])
\ No newline at end of file
+    assert set(step_types.values()) == set([step_object['step_type'] for step_object in STEPS] + ['initialize'])
+
+
+def test_user_json_fields_match():
+    user_json_fields = get_enum_from_ts_file('./src/api.tsx', 'UserJsonFields')
+    assert set(user_json_fields.values()) == set(USER_JSON_DEFAULT.keys())
\ No newline at end of file
