@@ -30,7 +30,9 @@ class MitoWidgetTestWrapper:
 
     @property
     def transpiled_code(self):
-        return transpile(self.mito_widget.widget_state_container)['code']
+        # NOTE: we don't add comments to this testing functionality, so that 
+        # we don't have to change tests if we update comments
+        return transpile(self.mito_widget.widget_state_container, add_comments=False)['code']
 
     def add_column(self, sheet_index: int, column_header: str, column_header_index=-1):
         """
