@@ -1,8 +1,3 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
 """
 conftest is the standard pytest testing config file, where
 we store decorators we use
@@ -15,15 +10,13 @@ import pytest
 from copy import deepcopy
 
 from mitosheet import __version__
-from mitosheet.experiments.experiment_utils import get_current_experiment
 from mitosheet.user import is_running_test
 from mitosheet.user.db import USER_JSON_PATH, get_user_field, get_user_json_object
-from mitosheet.user.schemas import UJ_EXPERIMENT, UJ_FEEDBACKS_V2, UJ_RECEIVED_CHECKLISTS, USER_JSON_DEFAULT
+from mitosheet.user.schemas import USER_JSON_DEFAULT
 from mitosheet.user.schemas import (
     UJ_USER_JSON_VERSION, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
     UJ_RECEIVED_TOURS, UJ_FEEDBACKS, UJ_MITOSHEET_CURRENT_VERSION, 
-    UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES,
-    UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY
+    UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES
 )
 
 today_str = datetime.today().strftime('%Y-%m-%d')
@@ -72,14 +65,9 @@ def check_user_json(
         user_email='github@action.com',
         received_tours=[],
         feedbacks=[],
-        feedbacks_v2={},
         mitosheet_current_version=__version__,
         mitosheet_last_upgraded_date=today_str,
         mitosheet_last_fifty_usages=[today_str],
-        mitosheet_telemetry=True,
-        mitosheet_is_pro=False,
-        mitosheet_experiment_id=None,
-        received_checklists={'onboarding_checklist': ['signup', 'import', 'filter','pivot','graph','finalize']},
     ):
     """
     This is the main helper function that does sanity checks about the 
@@ -89,21 +77,13 @@ def check_user_json(
     """
     assert set(get_user_json_object().keys()) == set(USER_JSON_DEFAULT.keys())
 
-    assert get_user_field(UJ_USER_JSON_VERSION) == 7
+    assert get_user_field(UJ_USER_JSON_VERSION) == 2
     assert len(get_user_field(UJ_STATIC_USER_ID)) > 0
     assert len(get_user_field(UJ_USER_SALT)) > 0
     assert (get_user_field(UJ_USER_EMAIL) == user_email or (get_user_field(UJ_USER_EMAIL) == 'github@action.com' and is_running_test()))
     assert get_user_field(UJ_RECEIVED_TOURS) == received_tours
     assert get_user_field(UJ_FEEDBACKS) == feedbacks
-    assert get_user_field(UJ_FEEDBACKS_V2) == feedbacks_v2
     assert get_user_field(UJ_MITOSHEET_CURRENT_VERSION) == mitosheet_current_version
     assert get_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE) == mitosheet_last_upgraded_date
     assert get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES) == mitosheet_last_fifty_usages
-    assert get_user_field(UJ_MITOSHEET_TELEMETRY) == mitosheet_telemetry
-    assert get_user_field(UJ_MITOSHEET_PRO) == mitosheet_is_pro
-    assert get_user_field(UJ_EXPERIMENT) is not None
-    assert get_user_field(UJ_RECEIVED_CHECKLISTS) == received_checklists or (get_user_field(UJ_RECEIVED_CHECKLISTS) == {})
-    if mitosheet_experiment_id:
-        assert get_user_field(UJ_EXPERIMENT)['experiment_id'] == mitosheet_experiment_id
-
 
