@@ -70,7 +70,7 @@ def should_display_feedback():
     """
     The user gives an initial piece of feedback when they first sign up
     for Mito. Thus, all users have 1 piece of feedback. 
-
+    
     We then expect them to give feedback on days: 2, 7, 20, 35, 49 
     of using the tool. We thus check the number of feedbacks they have
     given to that point.
@@ -83,9 +83,9 @@ def should_display_feedback():
     num_feedbacks = len(get_user_field(UJ_FEEDBACKS))
     num_days = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
 
-    return (num_feedbacks <= 1 and num_days >= 2) or \
-        (num_feedbacks <= 2 and num_days >= 7) or \
-        (num_feedbacks <= 3 and num_days >= 20) or \
-        (num_feedbacks <= 4 and num_days >= 35) or \
-        (num_feedbacks <= 5 and num_days >= 49)
+    return (num_feedbacks <= 1 and num_days == 2) or \
+        (num_feedbacks == 2 and num_days == 7) or \
+        (num_feedbacks <= 3 and num_days == 20) or \
+        (num_feedbacks <= 4 and num_days == 35) or \
+        (num_feedbacks <= 5 and num_days == 49)
 
