@@ -9,7 +9,7 @@ Contains helpful utility functions
 """
 from copy import deepcopy
 import json
-from mitosheet.sheet_functions.types.utils import get_datetime_columns, get_mito_type, get_timedelta_columns
+from mitosheet.sheet_functions.types.utils import get_datetime_columns, get_float_columns, get_mito_type, get_timedelta_columns
 import pandas as pd
 import numpy as np
 import numbers
@@ -132,6 +132,14 @@ def df_to_json_dumpsable(df: pd.DataFrame):
     for column_header in timedelta_columns:
         df[column_header] = df[column_header].apply(lambda x: str(x))
 
+    # Then, we get all the float columns and actually make them 
+    # look like floating point values, by converting them to strings
+    float_columns = get_float_columns(df)
+    for column_header in float_columns:
+        # Convert the value to a string if it is a number, but leave it alone if its a NaN 
+        # as to preserve the formatting of NaN values. 
+        df[column_header] = df[column_header].apply(lambda x: x if np.isnan(x) else str(x))
+
     json_obj = json.loads(df.to_json(orient="split"))
     # Then, we go through and find all the null values (which are infinities),
     # and set them to 'NaN' for display in the frontend.
